==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Image/Gui/Resources/translations/Image_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>图片</translation>
    </message>
    <message>
      <location/>
      <source>Create image plane...</source>
      <translation>创建图像平面...</translation>
    </message>
    <message>
      <location/>
      <source>create a planar image in the 3D space</source>
      <translation>三维空间中创建一个平面图像</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>图片</translation>
    </message>
    <message>
      <location/>
      <source>Open...</source>
      <translation>打开...</translation>
    </message>
    <message>
      <location/>
      <source>Open image view</source>
      <translation>打开图片视图</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>图片视图的色彩模式未定义</translation>
    </message>
    <message>
      <location/>
      <source>Image pixel format</source>
      <translation>图像像素格式</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location/>
      <source>&amp;Fit image</source>
      <translation>适应图像大小(&amp;F)</translation>
    </message>
    <message>
      <location/>
      <source>Stretch the image to fit the view</source>
      <translation>拉伸图像以适合视图</translation>
    </message>
    <message>
      <location/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 缩放</translation>
    </message>
    <message>
      <location/>
      <source>Display the image at a 1:1 scale</source>
      <translation>图像按1:1显示</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Original color</source>
      <translation>原始色(&amp;O)</translation>
    </message>
    <message>
      <location/>
      <source>Display the image with its original color(s)</source>
      <translation>以原始色显示图片</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Brightened color</source>
      <translation>高亮色(&amp;B)</translation>
    </message>
    <message>
      <location/>
      <source>Display the image with brightened color(s)</source>
      <translation>以高亮色显示图片</translation>
    </message>
    <message>
      <location/>
      <source>Standard</source>
      <translation>标准</translation>
    </message>
    <message>
      <location/>
      <source>Ready...</source>
      <translation>就绪...</translation>
    </message>
    <message>
      <location/>
      <source>grey</source>
      <translation>灰色</translation>
    </message>
    <message>
      <location/>
      <source>zoom</source>
      <translation>缩放</translation>
    </message>
    <message>
      <location/>
      <source>outside image</source>
      <translation>外部图像</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::Workbench</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>图片</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Image viewer</source>
      <translation>图片浏览器</translation>
    </message>
    <message>
      <location/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>图像(*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location/>
      <source>Choose an image file to open</source>
      <translation>选择并打开一个图片</translation>
    </message>
    <message>
      <location/>
      <source>Error open image</source>
      <translation>打开图像错误</translation>
    </message>
    <message>
      <location/>
      <source>Could not load the choosen image</source>
      <translation>无法加载选择的图片</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>图片</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Image/Gui/Resources/translations/Image_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>创建平面图像...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Create a planar image in the 3D space</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>三维空间中创建一个平面图像</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>图像</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>打开...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>打开图像视图</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+308"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>图片视图的色彩模式未定义</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>图像像素格式</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>适应图像尺寸(&amp;F)</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>拉伸图像以适应视图</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 缩放</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>按1:1比例显示图像</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>原始色(&amp;O)</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>以原始色显示图像</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>高亮色(&amp;B)</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>以高亮色显示图像</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>标准</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>就绪...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>灰色</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>缩放</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>图像外部</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>图像浏览器</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>图像(*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>选择一个图像文件打开</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Images</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>All files</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>打开图像错误</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>无法加载选择的图像</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>图像</translation>
    </message>
  </context>
</TS>
